package example.energy.coolemall;

import schedframe.Parameter;
import schedframe.resources.ResourceStatus;
import schedframe.resources.computing.ComputingResource;
import schedframe.resources.computing.Processor;
import schedframe.resources.computing.profiles.energy.EnergyEvent;
import schedframe.resources.computing.profiles.energy.power.StandardPowerStateName;
import schedframe.scheduling.manager.tasks.JobRegistry;
import example.energy.BaseEnergyEstimationPlugin;

public class ProcessorEnergyEstimationPlugin extends BaseEnergyEstimationPlugin  {

	public double estimatePowerConsumption(EnergyEvent event, JobRegistry jobRegistry,
			ComputingResource resource) {
		double powerConsumption = 0;
		Processor cpu = (Processor)resource;
		if(resource.getPowerInterface().getPowerState().equals(StandardPowerStateName.OFF))
			powerConsumption = 0;
		else {
			if(resource.getStatus() == ResourceStatus.BUSY){
				try {
					powerConsumption = cpu.getPowerInterface().getPowerConsumption(cpu.getPowerInterface().getPState());
				} catch (NoSuchFieldException e) {
					Parameter param = cpu.getResourceCharacteristic().getParameters().get("maxPower");
					if(param != null)
						powerConsumption = Double.valueOf(param.get(0).getContent());
				}
			}
			else {
				try {
					powerConsumption = cpu.getPowerInterface().getPowerConsumption(StandardPowerStateName.ON);
				} catch (NoSuchFieldException e) {
					Parameter param = cpu.getResourceCharacteristic().getParameters().get("maxPower");
					if(param != null)
						powerConsumption = 0.7 * Double.valueOf(param.get(0).getContent());
				}
			}
		}
		return powerConsumption;
	}

}
